@@ -15,6 +15,13 @@ class NoChromecastFoundError(PyChromecastError):
     pass
 
 
-class ConnectionError(PyChromecastError):
+class MultipleChromecastsFoundError(PyChromecastError):
+    """
+    When getting a singular chromecast results in getting multiple chromecasts.
+    """
+    pass
+
+
+class ChromecastConnectionError(PyChromecastError):
     """ When a connection error occurs within PyChromecast. """
     pass
